#[non_exhaustive]pub enum Network {
Bitcoin,
Testnet,
Testnet4,
Signet,
Regtest,
}Expand description
The cryptocurrency network to act on.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Bitcoin
Mainnet Bitcoin.
Testnet
Bitcoin’s testnet network. (In future versions this will be combined into a single variant containing the version)
Testnet4
Bitcoin’s testnet4 network. (In future versions this will be combined into a single variant containing the version)
Signet
Bitcoin’s signet network.
Regtest
Bitcoin’s regtest network.
Implementations
Sourceimpl Network
impl Network
Sourcepub fn from_magic(magic: Magic) -> Option<Network>
pub fn from_magic(magic: Magic) -> Option<Network>
Creates a Network from the magic bytes.
Examples
use bitcoin::p2p::Magic;
use bitcoin::Network;
assert_eq!(Ok(Network::Bitcoin), Network::try_from(Magic::from_bytes([0xF9, 0xBE, 0xB4, 0xD9])));
assert_eq!(None, Network::from_magic(Magic::from_bytes([0xFF, 0xFF, 0xFF, 0xFF])));Sourcepub fn magic(self) -> Magic
pub fn magic(self) -> Magic
Return the network magic bytes, which should be encoded little-endian at the start of every message
Examples
use bitcoin::p2p::Magic;
use bitcoin::Network;
let network = Network::Bitcoin;
assert_eq!(network.magic(), Magic::from_bytes([0xF9, 0xBE, 0xB4, 0xD9]));Sourcepub fn to_core_arg(self) -> &'static str
pub fn to_core_arg(self) -> &'static str
Converts a Network to its equivalent bitcoind -chain argument name.
$ bitcoin-23.0/bin/bitcoind --help | grep -C 3 '\-chain=<chain>'
Chain selection options:
-chain=<chain>
Use the chain <chain> (default: main). Allowed values: main, test, signet, regtestSourcepub fn from_core_arg(core_arg: &str) -> Result<Network, ParseNetworkError>
pub fn from_core_arg(core_arg: &str) -> Result<Network, ParseNetworkError>
Converts a bitcoind -chain argument name to its equivalent Network.
$ bitcoin-23.0/bin/bitcoind --help | grep -C 3 '\-chain=<chain>'
Chain selection options:
-chain=<chain>
Use the chain <chain> (default: main). Allowed values: main, test, signet, regtestSourcepub fn chain_hash(self) -> ChainHash
pub fn chain_hash(self) -> ChainHash
Return the network’s chain hash (genesis block hash).
Examples
use bitcoin::Network;
use bitcoin::blockdata::constants::ChainHash;
let network = Network::Bitcoin;
assert_eq!(network.chain_hash(), ChainHash::BITCOIN);Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Network
impl<'de> Deserialize<'de> for Network
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<Network, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Network, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Ord for Network
impl Ord for Network
Sourceimpl PartialOrd for Network
impl PartialOrd for Network
Sourceimpl Serialize for Network
impl Serialize for Network
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Copy for Network
impl Eq for Network
impl StructuralPartialEq for Network