pub struct CoreSystem { /* private fields */ }Expand description
Core functionality with auto-save capabilities. Provides performance optimization and input processing for the Anya system.
Implementations
Sourceimpl CoreSystem
impl CoreSystem
Sourcepub fn new(auto_save_frequency: usize) -> Self
pub fn new(auto_save_frequency: usize) -> Self
Creates a new core system with the specified auto-save frequency for each component.
Sourcepub fn performance_optimizer(&self) -> &PerformanceOptimizer
pub fn performance_optimizer(&self) -> &PerformanceOptimizer
Returns a reference to the performance optimizer.
Sourcepub fn process_input(&self, _input: &str) -> Result<(), String>
pub fn process_input(&self, _input: &str) -> Result<(), String>
Processes input across all components. Returns Ok if successful.
Sourcepub fn get_auto_save_stats(&self) -> (usize, usize, usize)
pub fn get_auto_save_stats(&self) -> (usize, usize, usize)
Gets stats about the auto-save state of all components. Returns a tuple of (agent_inputs, hardening_changes, performance_changes).