pub struct OracleClient {
pub oracle_pubkey: String,
pub attestations: HashMap<String, NonInteractiveOracleAttestation>,
}Expand description
[AIR-3][AIS-3][BPC-3][RES-3] Oracle Client for non-interactive oracle patterns This follows official Bitcoin Improvement Proposals (BIPs) standards for oracle interactions
Fields
oracle_pubkey: StringOracle public key in hex format
attestations: HashMap<String, NonInteractiveOracleAttestation>Map of event IDs to attestations
Implementations
Sourceimpl OracleClient
impl OracleClient
Sourcepub fn new(oracle_pubkey: &str) -> Self
pub fn new(oracle_pubkey: &str) -> Self
[AIR-3][AIS-3][BPC-3][RES-3] Create a new Oracle Client This follows official Bitcoin Improvement Proposals (BIPs) standards for oracle interactions
Sourcepub async fn get_event_info(&self, event_id: &str) -> DlcResult<OracleEvent>
pub async fn get_event_info(&self, event_id: &str) -> DlcResult<OracleEvent>
[AIR-3][AIS-3][BPC-3][RES-3] Get event information from the oracle This follows official Bitcoin Improvement Proposals (BIPs) standards for oracle interactions
Sourcepub fn verify_attestation(
&self,
_attestation: &OracleAttestation,
) -> DlcResult<bool>
pub fn verify_attestation( &self, _attestation: &OracleAttestation, ) -> DlcResult<bool>
[AIR-3][AIS-3][BPC-3][RES-3] Verify an oracle attestation This follows official Bitcoin Improvement Proposals (BIPs) standards for oracle attestations
Sourcepub async fn create_contract(
&mut self,
_contract_id: &str,
_contract_info: DlcContractInfo,
) -> Result<String, Box<dyn Error + Send + Sync>>
pub async fn create_contract( &mut self, _contract_id: &str, _contract_info: DlcContractInfo, ) -> Result<String, Box<dyn Error + Send + Sync>>
Create DLC contract with oracle
Sourcepub async fn close_contract(
&mut self,
_contract_id: &str,
) -> Result<(), Box<dyn Error + Send + Sync>>
pub async fn close_contract( &mut self, _contract_id: &str, ) -> Result<(), Box<dyn Error + Send + Sync>>
Close DLC contract
Sourcepub async fn get_signature(
&self,
event_id: &str,
) -> Result<Vec<u8>, Box<dyn Error + Send + Sync>>
pub async fn get_signature( &self, event_id: &str, ) -> Result<Vec<u8>, Box<dyn Error + Send + Sync>>
Get oracle signature for event
Sourcepub fn is_connected(&self) -> bool
pub fn is_connected(&self) -> bool
Check if oracle is connected
Sourcepub async fn create_dlc(
&mut self,
params: DlcParameters,
) -> Result<DlcContract, Box<dyn Error + Send + Sync>>
pub async fn create_dlc( &mut self, params: DlcParameters, ) -> Result<DlcContract, Box<dyn Error + Send + Sync>>
Create DLC with parameters
Sourceimpl OracleClient
[AIR-3][AIS-3][BPC-3][RES-3] Additional methods for OracleClient
impl OracleClient
[AIR-3][AIS-3][BPC-3][RES-3] Additional methods for OracleClient
Sourcepub async fn get_attestation(
&self,
event_id: &str,
) -> Result<NonInteractiveOracleAttestation, DlcError>
pub async fn get_attestation( &self, event_id: &str, ) -> Result<NonInteractiveOracleAttestation, DlcError>
Get attestation for an event [AIR-3][AIS-3][BPC-3][RES-3]