pub struct MockLayer2Protocol { /* private fields */ }Implementations
Sourceimpl MockLayer2Protocol
impl MockLayer2Protocol
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockLayer2Protocol
impl MockLayer2Protocol
Sourcepub fn expect_initialize(&mut self) -> &mut Expectation
pub fn expect_initialize(&mut self) -> &mut Expectation
Create an Expectation for mocking the initialize method
Sourcepub fn expect_connect(&mut self) -> &mut Expectation
pub fn expect_connect(&mut self) -> &mut Expectation
Create an Expectation for mocking the connect method
Sourcepub fn expect_get_state(&mut self) -> &mut Expectation
pub fn expect_get_state(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_state method
Sourcepub fn expect_submit_transaction(&mut self) -> &mut Expectation
pub fn expect_submit_transaction(&mut self) -> &mut Expectation
Create an Expectation for mocking the submit_transaction method
Sourcepub fn expect_check_transaction_status(&mut self) -> &mut Expectation
pub fn expect_check_transaction_status(&mut self) -> &mut Expectation
Create an Expectation for mocking the check_transaction_status method
Sourcepub fn expect_sync_state(&mut self) -> &mut Expectation
pub fn expect_sync_state(&mut self) -> &mut Expectation
Create an Expectation for mocking the sync_state method
Sourcepub fn expect_issue_asset(&mut self) -> &mut Expectation
pub fn expect_issue_asset(&mut self) -> &mut Expectation
Create an Expectation for mocking the issue_asset method
Sourcepub fn expect_transfer_asset(&mut self) -> &mut Expectation
pub fn expect_transfer_asset(&mut self) -> &mut Expectation
Create an Expectation for mocking the transfer_asset method
Sourcepub fn expect_verify_proof(&mut self) -> &mut Expectation
pub fn expect_verify_proof(&mut self) -> &mut Expectation
Create an Expectation for mocking the verify_proof method
Sourcepub fn expect_validate_state(&mut self) -> &mut Expectation
pub fn expect_validate_state(&mut self) -> &mut Expectation
Create an Expectation for mocking the validate_state method