MockLayer2Protocol

Struct MockLayer2Protocol 

pub struct MockLayer2Protocol { /* private fields */ }

Implementations

Source

impl MockLayer2Protocol

pub fn checkpoint(&mut self)

Validate that all current expectations for all methods have been satisfied, and discard them.

pub fn new() -> Self

Create a new mock object with no expectations.

This method will not be generated if the real struct already has a new method. However, it will be generated if the struct implements a trait with a new method. The trait’s new method can still be called like <MockX as TraitY>::new

Source

impl MockLayer2Protocol

pub fn expect_initialize(&mut self) -> &mut Expectation

Create an Expectation for mocking the initialize method

pub fn expect_connect(&mut self) -> &mut Expectation

Create an Expectation for mocking the connect method

pub fn expect_get_state(&mut self) -> &mut Expectation

Create an Expectation for mocking the get_state method

pub fn expect_submit_transaction(&mut self) -> &mut Expectation

Create an Expectation for mocking the submit_transaction method

pub fn expect_check_transaction_status(&mut self) -> &mut Expectation

Create an Expectation for mocking the check_transaction_status method

pub fn expect_sync_state(&mut self) -> &mut Expectation

Create an Expectation for mocking the sync_state method

pub fn expect_issue_asset(&mut self) -> &mut Expectation

Create an Expectation for mocking the issue_asset method

pub fn expect_transfer_asset(&mut self) -> &mut Expectation

Create an Expectation for mocking the transfer_asset method

pub fn expect_verify_proof(&mut self) -> &mut Expectation

Create an Expectation for mocking the verify_proof method

pub fn expect_validate_state(&mut self) -> &mut Expectation

Create an Expectation for mocking the validate_state method